@@ -83,35 +83,35 @@ public class EPPUtil {
 	private static DecimalFormatSymbols decimalFormatSymbols = new DecimalFormatSymbols(
 			Locale.US);
 
-    /**
-     * Gets the XML Schema <code>timeDate</code> format used 
-     * in {@link #encodeTimeInstant(Date) and #encodeTimeInstant(Document, Element,
-	 * Date, String, String)}.  The defauLt format is defined by the constant 
-	 * {@link #DEFAULT_TIME_INSTANT_FORMAT} and it can be overridden using 
-	 * the {@link #setTimeInstantFormat(String)} method.  
-	 *     
-     * @return XML Schema <code>timeDate</code> format used 
-     * in {@link #encodeTimeInstant(Date) and #encodeTimeInstant(Document, Element,
-	 * Date, String, String)}.
-     */
+	/**
+	 * Gets the XML Schema <code>timeDate</code> format used in
+	 * {@link #encodeTimeInstant(Date) and #encodeTimeInstant(Document, Element,
+	 * Date, String, String)}. The defauLt format is defined by the constant
+	 * {@link #DEFAULT_TIME_INSTANT_FORMAT} and it can be overridden using the
+	 * {@link #setTimeInstantFormat(String)} method.
+	 * 
+	 * @return XML Schema <code>timeDate</code> format used in
+	 *         {@link #encodeTimeInstant(Date) and #encodeTimeInstant(Document,
+	 *         Element, Date, String, String)}.
+	 */
 	public static String getTimeInstantFormat() {
 		return timeInstantFormat;
 	}
 
 	/**
-	 * Sets the XML Schema <code>timeDate</code> format used 
-     * in {@link #encodeTimeInstant(Date) and #encodeTimeInstant(Document, Element,
-	 * Date, String, String)}.  The format must follow the format 
-	 * supported by {@link SimpleDateFormat}.    
+	 * Sets the XML Schema <code>timeDate</code> format used in
+	 * {@link #encodeTimeInstant(Date) and #encodeTimeInstant(Document, Element,
+	 * Date, String, String)}. The format must follow the format supported by
+	 * {@link SimpleDateFormat}.
 	 * 
-	 * @param aTimeInstantFormat XML Schema <code>timeDate</code> format 
-	 * supported by {@link SimpleDateFormat}. 
+	 * @param aTimeInstantFormat
+	 *            XML Schema <code>timeDate</code> format supported by
+	 *            {@link SimpleDateFormat}.
 	 */
 	public static void setTimeInstantFormat(String aTimeInstantFormat) {
 		timeInstantFormat = aTimeInstantFormat;
 	}
-	
-	
+
 	/**
 	 * Appends the children Nodes of <code>aSource</code> as children nodes of
 	 * <code>aDest</code>.
@@ -159,9 +159,28 @@ public class EPPUtil {
 
 		Element theElm = EPPUtil.getElementByTagNameNS(aElement, aNS, aTagName);
 
+		return EPPUtil.decodeBigDecimal(theElm);
+	}
+
+	/**
+	 * Decode <code>BigDecimal</code>, from an XML Element. The
+	 * <code>aElement</code> element will be decoded and returned. If element is
+	 * <code>null</code>, <code>null</code> is returned.
+	 * 
+	 * @param aElement
+	 *            XML Element to decode.
+	 * @return <code>BigDecimal</code> value if <code>aElement</code> is not
+	 *         <code>null</code>; <code>null</code> otherwise.
+	 * @exception EPPDecodeException
+	 *                Error decoding <code>aElement</code>.
+	 */
+	public static BigDecimal decodeBigDecimal(Element aElement)
+			throws EPPDecodeException {
+
 		BigDecimal retBigDecimal = null;
-		if (theElm != null) {
-			Node textNode = theElm.getFirstChild();
+
+		if (aElement != null) {
+			Node textNode = aElement.getFirstChild();
 
 			// Element does have a text node?
 			if (textNode != null) {
@@ -188,8 +207,6 @@ public class EPPUtil {
 		return retBigDecimal;
 	}
 
-	// End EPPUtil.decodeDate(String)
-
 	/**
 	 * Decode <code>Boolean</code>, by XML namespace and tag name, from an XML
 	 * Element. The children elements of <code>aElement</code> will be searched
@@ -496,7 +513,7 @@ public class EPPUtil {
 	 * @return Java Date object.
 	 */
 	public static Date decodeDate(String aDateValue) {
-		
+
 		SimpleDateFormat formatter = new SimpleDateFormat(DATE_FORMAT);
 
 		// Set to UTC with no time element
@@ -508,7 +525,7 @@ public class EPPUtil {
 		formatter.setCalendar(theCal);
 
 		Date theDate = formatter.parse(aDateValue, new ParsePosition(0));
-		
+
 		return theDate;
 	}
 
@@ -693,7 +710,7 @@ public class EPPUtil {
 	}
 
 	/**
-	 * Decode an XML Schema timeInstant data type to a Java Date object. 
+	 * Decode an XML Schema timeInstant data type to a Java Date object.
 	 * 
 	 * @param aTimeInstant
 	 *            XML Schema timeInstant data type string.
@@ -702,7 +719,7 @@ public class EPPUtil {
 	 */
 	public static Date decodeTimeInstant(String aTimeInstant) {
 		Date theDate = null;
-		
+
 		try {
 			theDate = DatatypeConverter.parseDateTime(aTimeInstant).getTime();
 		}
@@ -710,7 +727,7 @@ public class EPPUtil {
 			cat.error("Exception decoding dataTime: " + ex);
 			theDate = null;
 		}
-		
+
 		return theDate;
 	}
 
@@ -782,6 +799,10 @@ public class EPPUtil {
 	 *            Tag name of the element including an optional namespace
 	 *            prefix. For example, the tag name for the domain name is
 	 *            "domain:name".
+	 * @param aFormat
+	 *            Format to use following the {@link DecimalFormat} format. If
+	 *            <code>null</code> is passed, the default format of &quot;#0.00&quot; is
+	 *            used.
 	 * @exception EPPEncodeException
 	 *                Error encoding the <code>Double</code>.
 	 */
@@ -800,6 +821,39 @@ public class EPPUtil {
 		}
 	}
 
+	/**
+	 * Encode a <code>Double</code> in XML with a given XML namespace and tag
+	 * name. Takes an optional argument for the format of the Double, if not
+	 * provided then it uses #0.00 which formats the double to 2 decimal places.
+	 * 
+	 * @param aElement
+	 *            XML Element to add the text node encoded with the <code>BigDecimal</code> value.
+	 * @param aBigDecimal
+	 *            <code>Double</code> to encode into the text node of the element.
+	 * @param aFormat
+	 *            Format to use following the {@link DecimalFormat} format. If
+	 *            <code>null</code> is passed, the default format of &quot;#0.00&quot; is
+	 *            used.
+	 * @exception EPPEncodeException
+	 *                Error encoding the <code>Double</code>.
+	 */
+	public static void encodeBigDecimal(Document aDocument, Element aElement, BigDecimal aBigDecimal, String aFormat)
+			throws EPPEncodeException {
+		
+		if (aBigDecimal != null) {
+
+			String format = aFormat != null ? aFormat : "#0.00";
+			DecimalFormat decFormat = new DecimalFormat(format,
+					decimalFormatSymbols);
+
+			String numberStr = decFormat.format(aBigDecimal);
+			
+			// Add text node
+			Text currVal = aDocument.createTextNode(numberStr);
+			aElement.appendChild(currVal);
+		}
+	}
+
 	/**
 	 * Encode a <code>Boolean</code> in XML with a given XML namespace and tag
 	 * name. If aBoolean is <code>null</code> an element is not added.
@@ -939,7 +993,8 @@ public class EPPUtil {
 	 *            XML Element to add children nodes to. For example, the root
 	 *            node could be &ltdomain:update&gt
 	 * @param aVector
-	 *            <code>Vector</code> of <code>EPPCodecComponent's</code> to add.
+	 *            <code>Vector</code> of <code>EPPCodecComponent's</code> to
+	 *            add.
 	 * @exception EPPEncodeException
 	 *                Error encoding the <code>Vector</code> of
 	 *                <code>EPPCodecComponent</code>'s.
@@ -1598,9 +1653,9 @@ public class EPPUtil {
 
 		return ret;
 	}
-	
+
 	/**
-	 * Converts an <code>aElement</code> to a <code>String</code> for printing 
+	 * Converts an <code>aElement</code> to a <code>String</code> for printing
 	 * without pretty printing.
 	 * 
 	 * @param aElement
@@ -1628,7 +1683,6 @@ public class EPPUtil {
 
 		return ret;
 	}
-	
 
 	/**
 	 * Determines if one <code>Vector</code> is a subset of another
@@ -1847,17 +1901,19 @@ public class EPPUtil {
 	/**
 	 * Base64 encode the XML <code>Element</code> tree.
 	 * 
-	 * @param aElement Root element to encode in Base64
+	 * @param aElement
+	 *            Root element to encode in Base64
 	 * @return Base64 encoded value of the XML <code>Element</code> tree.
-	 * @throws Exception Error encoding the <code>Element</code>
+	 * @throws Exception
+	 *             Error encoding the <code>Element</code>
 	 */
 	public static String encodeBase64(Element aElement) throws Exception {
 		ByteArrayOutputStream ostream = new ByteArrayOutputStream();
-		
+
 		TransformerFactory transFac = TransformerFactory.newInstance();
 		Transformer trans = transFac.newTransformer();
 		trans.transform(new DOMSource(aElement), new StreamResult(ostream));
-		
+
 		return (new String(Base64.encodeBase64(ostream.toByteArray(), true)));
 	}
 
