@@ -92,7 +92,7 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	/**
 	 * Claims notice information used for Claims Create Form
 	 */
-	EPPLaunchNotice notice;
+	List<EPPLaunchNotice> notices = new ArrayList<EPPLaunchNotice>();
 
 	/**
 	 * Defines the expected type of object to create. The default value is
@@ -158,13 +158,13 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 *            Type of object to create (<code>TYPE_APPLICATION</code> or
 	 *            <code>TYPE_REGISTRATION</code>)
 	 */
-	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPSignedMark aSignedMark, String aType) {
+	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPSignedMark aSignedMark,
+			String aType) {
 		this.phase = aPhase;
 		this.setSignedMark(aSignedMark);
 		this.type = aType;
 	}
-	
-	
+
 	/**
 	 * Create a <code>EPPLaunchCreate</code> instance with the required phase
 	 * and a single code mark.
@@ -178,7 +178,7 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 		this.phase = aPhase;
 		this.setCodeMark(aCodeMark);
 	}
-	
+
 	/**
 	 * Create a <code>EPPLaunchCreate</code> instance with the required phase
 	 * and a single code mark and the optional type.
@@ -191,12 +191,12 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 *            Type of object to create (<code>TYPE_APPLICATION</code> or
 	 *            <code>TYPE_REGISTRATION</code>)
 	 */
-	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPLaunchCodeMark aCodeMark, String aType) {
+	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPLaunchCodeMark aCodeMark,
+			String aType) {
 		this.phase = aPhase;
 		this.setCodeMark(aCodeMark);
 		this.type = aType;
 	}
-	
 
 	/**
 	 * Create a <code>EPPLaunchCreate</code> instance with the required phase
@@ -209,12 +209,13 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 */
 	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPLaunchNotice aNotice) {
 		this.phase = aPhase;
-		this.notice = aNotice;
+		this.addNotice(aNotice);
 	}
-	
+
 	/**
 	 * Create a <code>EPPLaunchCreate</code> instance with the required phase
-	 * and the claims notice information for Claims Create Form and optional type.
+	 * and the claims notice information for Claims Create Form and optional
+	 * type.
 	 * 
 	 * @param aPhase
 	 *            Phase of the create
@@ -224,24 +225,23 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 *            Type of object to create (<code>TYPE_APPLICATION</code> or
 	 *            <code>TYPE_REGISTRATION</code>)
 	 */
-	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPLaunchNotice aNotice, String aType) {
+	public EPPLaunchCreate(EPPLaunchPhase aPhase, EPPLaunchNotice aNotice,
+			String aType) {
 		this.phase = aPhase;
-		this.notice = aNotice;
+		this.addNotice(aNotice);
 		this.type = aType;
 	}
-	
 
 	/**
 	 * Is the type defined?
 	 * 
-	 * @return <code>true</code> if the type is defined;
-	 *         <code>false</code> otherwise.
+	 * @return <code>true</code> if the type is defined; <code>false</code>
+	 *         otherwise.
 	 */
 	public boolean hasType() {
 		return (this.type != null ? true : false);
 	}
-	
-	
+
 	/**
 	 * Gets the type of the object to create, which should be either
 	 * <code>TYPE_APPLICATION</code>, <code>TYPE_REGISTRATION</code>, or
@@ -265,6 +265,7 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 		this.type = aType;
 	}
 
+	
 	/**
 	 * Gets phase associated with the create command.
 	 * 
@@ -434,7 +435,7 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 *         <code>false</code> otherwise.
 	 */
 	public boolean hasNotice() {
-		return (this.notice != null ? true : false);
+		return (!this.notices.isEmpty() ? true : false);
 	}
 
 	/**
@@ -443,7 +444,19 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 * @return Claims notice information if set; <code>null</code> otherwise.
 	 */
 	public EPPLaunchNotice getNotice() {
-		return this.notice;
+		if (!this.notices.isEmpty()) {
+			return this.notices.get(0);
+		}
+		else
+			return null;
+	}
+
+	/**
+	 * Clear the claim notices set. The result will be an empty claim notice
+	 * list.
+	 */
+	public void clearNotices() {
+		this.notices = new ArrayList<EPPLaunchNotice>();
 	}
 
 	/**
@@ -453,7 +466,43 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	 *            Claims notice information.
 	 */
 	public void setNotice(EPPLaunchNotice aNotice) {
-		this.notice = aNotice;
+		this.clearNotices();
+		this.addNotice(aNotice);
+	}
+
+	/**
+	 * Returns the list of notices.
+	 * 
+	 * @return List of notices; empty list if no notices set.
+	 */
+	public List<EPPLaunchNotice> getNotices() {
+		return this.notices;
+	}
+
+	/**
+	 * Sets the list of notices.
+	 * 
+	 * @param aNotices
+	 *            Notices to set. If <code>aNotices</code> is <code>null</code>
+	 *            the list will be set to the empty list.
+	 */
+	public void setNotices(List<EPPLaunchNotice> aNotices) {
+		if (aNotices != null) {
+			this.notices = aNotices;
+		}
+		else {
+			this.clearNotices();
+		}
+	}
+
+	/**
+	 * Adds a claims notice to the list of claims notices in Claims Create Form.
+	 * 
+	 * @param aNotice
+	 *            Claims notice information.
+	 */
+	public void addNotice(EPPLaunchNotice aNotice) {
+		this.notices.add(aNotice);
 	}
 
 	/**
@@ -466,6 +515,13 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	public Object clone() throws CloneNotSupportedException {
 
 		EPPLaunchCreate clone = (EPPLaunchCreate) super.clone();
+
+		clone.notices = new ArrayList<EPPLaunchNotice>();
+
+		for (EPPLaunchNotice notice : this.notices) {
+			clone.notices.add((EPPLaunchNotice) notice.clone());
+		}
+
 		return clone;
 	}
 
@@ -492,8 +548,6 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 					"EPPLaunchCreate phase attribute must be set.");
 		}
 
-		boolean extTypeFound = false;
-
 		if (this.signedMarks != null && this.codeMarks != null) {
 			throw new EPPEncodeException(
 					"EPPLaunchCreate more than one type of extension defined (signedMark and codeMark).");
@@ -525,8 +579,8 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 		// Code Mark
 		EPPUtil.encodeCompList(aDocument, root, this.codeMarks);
 
-		// Claim Notice
-		EPPUtil.encodeComp(aDocument, root, this.notice);
+		// Claim Notices
+		EPPUtil.encodeCompList(aDocument, root, this.notices);
 
 		return root;
 	}
@@ -573,14 +627,11 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 			this.codeMarks = null;
 		}
 
-		// Claim Notice
-		this.notice = (EPPLaunchNotice) EPPUtil.decodeComp(aElement,
-				EPPLaunchExtFactory.NS, EPPLaunchNotice.ELM_NAME,
-				EPPLaunchNotice.class);
+		// Claim Notices
+		this.notices = EPPUtil.decodeCompList(aElement, EPPLaunchExtFactory.NS,
+				EPPLaunchNotice.ELM_NAME, EPPLaunchNotice.class);
 	}
 
-	
-	
 	/**
 	 * implements a deep <code>EPPLaunchCreate</code> compare.
 	 * 
@@ -625,9 +676,9 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 			return false;
 		}
 
-		// Claim Notice
-		if (!EqualityUtil.equals(this.notice, other.notice)) {
-			cat.error("EPPLaunchCreate.equals(): notice not equal");
+		// Claim Notices
+		if (!EqualityUtil.equals(this.notices, other.notices)) {
+			cat.error("EPPLaunchCreate.equals(): notices not equal");
 			return false;
 		}
 
@@ -645,14 +696,16 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
-	
+
 	/**
-	 * Decodes the list of signed marks that can be either 
-	 * encoded signed marks or signed marks.  
+	 * Decodes the list of signed marks that can be either encoded signed marks
+	 * or signed marks.
 	 * 
-	 * @param aElement Parent element containing the list of signed marks
-	 * @return List of {@link EPPImmutableSignedMark} instances.  
-	 * @throws EPPDecodeException Error decoding the signed mark
+	 * @param aElement
+	 *            Parent element containing the list of signed marks
+	 * @return List of {@link EPPImmutableSignedMark} instances.
+	 * @throws EPPDecodeException
+	 *             Error decoding the signed mark
 	 */
 	private List decodeSignedMarkList(Element aElement)
 			throws EPPDecodeException {
@@ -661,17 +714,18 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 		Vector theChildren = EPPUtil.getElementsByTagNameNS(aElement,
 				EPPSignedMark.NS,
 				EPPEncodedSignedMark.ELM_ENCODED_SIGNED_MARK_LOCALNAME);
-		
+
 		if (theChildren.size() != 0) {
 			// For each signed mark (encoded or not)
 			for (int i = 0; i < theChildren.size(); i++) {
 				EPPSignedMark signedMark;
 				try {
 					signedMark = new EPPEncodedSignedMark();
-					signedMark.decode((Element) theChildren.elementAt(i));	
+					signedMark.decode((Element) theChildren.elementAt(i));
 				}
 				catch (EPPException e) {
-					throw new EPPDecodeException("Error decoding signed mark: " + e);
+					throw new EPPDecodeException("Error decoding signed mark: "
+							+ e);
 				}
 				retVal.add(signedMark);
 			}
@@ -679,7 +733,7 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 		else {
 			theChildren = EPPUtil.getElementsByTagNameNS(aElement,
 					EPPSignedMark.NS, EPPSignedMark.ELM_SIGNED_MARK_LOCALNAME);
-		
+
 			// For each signed mark (encoded or not)
 			for (int i = 0; i < theChildren.size(); i++) {
 				EPPSignedMark signedMark;
@@ -688,15 +742,15 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 					signedMark.decode((Element) theChildren.elementAt(i));
 				}
 				catch (EPPException e) {
-					throw new EPPDecodeException("Error decoding signed mark: " + e);
+					throw new EPPDecodeException("Error decoding signed mark: "
+							+ e);
 				}
 				retVal.add(signedMark);
 			}
-			
+
 		}
 
 		return retVal;
 	}
-	
 
 }
\ No newline at end of file
