@@ -153,13 +153,12 @@ public class EPPLaunchTst extends TestCase {
 	 * marks.
 	 */
 	private static final String TRUSTSTORE_FILENAME = "signedMarkTrust.jks";
-	
+
 	/**
-	 * Root directory containing the sample Signed Mark Data (SMD)'s.  
+	 * Root directory containing the sample Signed Mark Data (SMD)'s.
 	 */
 	private static String smdsDir;
 
-
 	/**
 	 * Creates a new EPPLaunchTst object.
 	 * 
@@ -170,8 +169,6 @@ public class EPPLaunchTst extends TestCase {
 		super(name);
 	}
 
-	
-	
 	/**
 	 * Tests the <code>EPPSignedMark</code> class. The tests include the
 	 * following:<br>
@@ -293,7 +290,7 @@ public class EPPLaunchTst extends TestCase {
 			signedMark = new EPPSignedMark("1-2", issuer,
 					new GregorianCalendar(2009, 8, 16).getTime(),
 					new GregorianCalendar(2010, 8, 16).getTime(), mark);
-			
+
 			signedMark.sign(privateKey);
 		}
 		catch (EPPException ex) {
@@ -312,22 +309,23 @@ public class EPPLaunchTst extends TestCase {
 		 * using CA certificate
 		 */
 		try {
-			signedMark = new EPPSignedMark("2-2", issuer, new GregorianCalendar(
-					2009, 8, 16).getTime(),
+			signedMark = new EPPSignedMark("2-2", issuer,
+					new GregorianCalendar(2009, 8, 16).getTime(),
 					new GregorianCalendar(2010, 8, 16).getTime(), mark);
-			
+
 			signedMark.sign(privateKey, certChain);
 		}
 		catch (EPPException ex) {
 			Assert.fail("testSignedMark(): [2] Error signing the signed mark with private key and certificates: "
 					+ ex);
 		}
-		
+
 		// Create SMD of signed mark to vrsnSignedMark.smd
 		try {
 			byte[] smdXml = signedMark.encode();
 			byte[] smdBase64 = Base64.encodeBase64(smdXml, true);
-			FileOutputStream outStream = new FileOutputStream("vrsnSignedMark.smd");
+			FileOutputStream outStream = new FileOutputStream(
+					"vrsnSignedMark.smd");
 			outStream.write("-----BEGIN ENCODED SMD-----\n".getBytes());
 			outStream.write(smdBase64);
 			outStream.write("-----END ENCODED SMD-----\n".getBytes());
@@ -337,10 +335,11 @@ public class EPPLaunchTst extends TestCase {
 			Assert.fail("testSignedMark(): [2] Error creating vrsnSignedMark.smd SMD file for signed mark: "
 					+ ex);
 		}
-		
+
 		// Create XML signed mark pretty printed
 		try {
-			FileOutputStream outStream = new FileOutputStream("vrsnSignedMark.xml");
+			FileOutputStream outStream = new FileOutputStream(
+					"vrsnSignedMark.xml");
 			outStream.write(signedMark.toString().getBytes());
 			outStream.close();
 		}
@@ -348,8 +347,6 @@ public class EPPLaunchTst extends TestCase {
 			Assert.fail("testSignedMark(): [2] Error creating vrsnSignedMark.xml file for signed mark: "
 					+ ex);
 		}
-		
-		
 
 		if (!signedMark.validate(pkixParameters)) {
 			Assert.fail("testSignedMark(): [2] Error validating with CA certificate");
@@ -386,12 +383,13 @@ public class EPPLaunchTst extends TestCase {
 					+ new String(signedMarkXml2) + "]");
 
 			// Original signed mark matches decoded signed mark?
-//			int compareVal = (new String(signedMarkXml)).compareTo(new String(
-//					signedMarkXml2));
-//			if (compareVal != 0) {
-//				Assert.fail("testSignedMark(): [3] The signed mark XML is not equal, with compare value = "
-//						+ compareVal);
-//			}
+			// int compareVal = (new String(signedMarkXml)).compareTo(new
+			// String(
+			// signedMarkXml2));
+			// if (compareVal != 0) {
+			// Assert.fail("testSignedMark(): [3] The signed mark XML is not equal, with compare value = "
+			// + compareVal);
+			// }
 
 			if (!signedMark2.validate(publicKey)) {
 				Assert.fail("testSignedMark(): [3] Signed mark validation using public key error with encode/decode");
@@ -406,15 +404,15 @@ public class EPPLaunchTst extends TestCase {
 		}
 
 		System.out.println("testSignedMark(): [3] Success");
-		
-		
+
 		/**
-		 * [3.1] Test creating immutable signed mark from a signed mark and validating it.  
+		 * [3.1] Test creating immutable signed mark from a signed mark and
+		 * validating it.
 		 */
 		EPPSignedMark signedMark3 = null;
 		byte[] signedMarkXml3 = {};
 		try {
-			signedMark3 = new EPPSignedMark(signedMarkXml);			
+			signedMark3 = new EPPSignedMark(signedMarkXml);
 		}
 		catch (EPPException e) {
 			Assert.fail("testSignedMark(): [3.1] Error creating decoding signed mark: "
@@ -426,8 +424,6 @@ public class EPPLaunchTst extends TestCase {
 		if (!signedMark2.validate(pkixParameters)) {
 			Assert.fail("testSignedMark(): [3.1] Signed mark validation using PKIXParameters (trust store) error with encode/decode");
 		}
-		
-			
 
 		/**
 		 * [4] Test base64 encoding and decoding and XML signature validation
@@ -454,12 +450,13 @@ public class EPPLaunchTst extends TestCase {
 					.println("testSignedMark(): [4] Signed Encoded Mark XML 2 = ["
 							+ new String(signedMarkXml2) + "]");
 
-//			int compareVal = (new String(signedMarkXml)).compareTo(new String(
-//					signedMarkXml2));
-//			if (compareVal != 0) {
-//				Assert.fail("testSignedMark(): [4] The encoded signed mark XML is not equal, with compare value = "
-//						+ compareVal);
-//			}
+			// int compareVal = (new String(signedMarkXml)).compareTo(new
+			// String(
+			// signedMarkXml2));
+			// if (compareVal != 0) {
+			// Assert.fail("testSignedMark(): [4] The encoded signed mark XML is not equal, with compare value = "
+			// + compareVal);
+			// }
 
 			if (!signedMark2.validate(publicKey)) {
 				Assert.fail("testSignedMark(): [4] Encoded signed mark validation using public key error with encode/decode");
@@ -474,7 +471,7 @@ public class EPPLaunchTst extends TestCase {
 		}
 
 		System.out.println("testSignedMark(): [4] Success");
-		
+
 		/**
 		 * [5] Test signing and verification with revoked certificate
 		 */
@@ -494,12 +491,11 @@ public class EPPLaunchTst extends TestCase {
 					+ ex);
 		}
 
-
 		try {
-			signedMark = new EPPSignedMark("5-2", issuer, new GregorianCalendar(
-					2012, 8, 16).getTime(),
+			signedMark = new EPPSignedMark("5-2", issuer,
+					new GregorianCalendar(2012, 8, 16).getTime(),
 					new GregorianCalendar(2013, 8, 16).getTime(), mark);
-			
+
 			signedMark.sign(revokedPrivateKey);
 		}
 		catch (EPPException ex) {
@@ -512,16 +508,13 @@ public class EPPLaunchTst extends TestCase {
 		}
 
 		System.out.println("testSignedMark(): [5] Success");
-		
 
 		EPPCodecTst.printEnd("testSignedMark");
 	}
-	
-	
+
 	/**
-	 * Tests the <code>EPPSignedMark</code> class using the 
-	 * exact attributes defined in the SMD sample 
-	 * Trademark-Holder-English-Active.smd. 
+	 * Tests the <code>EPPSignedMark</code> class using the exact attributes
+	 * defined in the SMD sample Trademark-Holder-English-Active.smd.
 	 */
 	public void testTrademarkHolderEnglishActive() {
 		EPPCodecTst.printStart("testTrademarkHolderEnglishActive");
@@ -534,7 +527,7 @@ public class EPPLaunchTst extends TestCase {
 		holder.setEmail("info@example.example");
 		holder.setVoice("+1.3014556600");
 		holder.setVoice("+1.3014556601");
-		
+
 		// Address
 		EPPMarkAddress holderAddress = new EPPMarkAddress();
 		holderAddress.addStreet("101 West Arques Avenue");
@@ -561,11 +554,12 @@ public class EPPLaunchTst extends TestCase {
 		trademark.addLabel("testet-validate");
 		trademark.addLabel("testetvalidate");
 		trademark.addLabel("testvalidate");
-		trademark
-				.setGoodsAndServices("guitar");
+		trademark.setGoodsAndServices("guitar");
 		trademark.setRegNum("1234");
-		trademark.setRegDate(EPPUtil.decodeTimeInstant("2012-12-31T23:00:00.000Z"));
-		trademark.setExDate(EPPUtil.decodeTimeInstant("2014-12-31T23:00:00.000Z"));
+		trademark.setRegDate(EPPUtil
+				.decodeTimeInstant("2012-12-31T23:00:00.000Z"));
+		trademark.setExDate(EPPUtil
+				.decodeTimeInstant("2014-12-31T23:00:00.000Z"));
 
 		// Mark
 		EPPMark mark = new EPPMark();
@@ -582,9 +576,10 @@ public class EPPLaunchTst extends TestCase {
 		 */
 		EPPSignedMark signedMark = null;
 		// TODO - Get a way to explicitly set the ID attribute.
-//		signedMark.setAttrIdValue("_b1462c28-996c-45b0-a053-a23d76e7836f");
+		// signedMark.setAttrIdValue("_b1462c28-996c-45b0-a053-a23d76e7836f");
 		try {
-			signedMark = new EPPSignedMark("0000001701373633628125-65535", issuer,
+			signedMark = new EPPSignedMark("0000001701373633628125-65535",
+					issuer,
 					EPPUtil.decodeTimeInstant("2013-07-12T12:53:48.125Z"),
 					EPPUtil.decodeTimeInstant("2017-07-09T22:00:00.000Z"), mark);
 
@@ -594,31 +589,33 @@ public class EPPLaunchTst extends TestCase {
 			Assert.fail("testTrademarkHolderEnglishActive(): Error signing the signed mark with private key and certificates: "
 					+ ex);
 		}
-		
+
 		if (!signedMark.validate(pkixParameters)) {
 			Assert.fail("testTrademarkHolderEnglishActive(): Error validating with CA certificate");
-		}		
-		
+		}
+
 		// Create SMD of signed mark to vrsnSignedMark.smd
 		byte[] smdXml = null;
 		try {
 			smdXml = signedMark.encode();
 			byte[] smdBase64 = Base64.encodeBase64(smdXml, true);
-			FileOutputStream outStream = new FileOutputStream("VRSN-Trademark-Holder-English-Active.smd");
+			FileOutputStream outStream = new FileOutputStream(
+					"VRSN-Trademark-Holder-English-Active.smd");
 			outStream.write("-----BEGIN ENCODED SMD-----\n".getBytes());
 			outStream.write(smdBase64);
 			outStream.write("-----END ENCODED SMD-----\n".getBytes());
 			outStream.close();
-			
+
 		}
 		catch (Exception ex) {
 			Assert.fail("testTrademarkHolderEnglishActive(): Error creating Trademark-Holder-English-Active.smd SMD file for signed mark: "
 					+ ex);
 		}
-		
+
 		// Create XML signed mark pretty printed
 		try {
-			FileOutputStream outStream = new FileOutputStream("VRSN-Trademark-Holder-English-Active.xml");
+			FileOutputStream outStream = new FileOutputStream(
+					"VRSN-Trademark-Holder-English-Active.xml");
 			outStream.write(signedMark.toString().getBytes());
 			outStream.close();
 		}
@@ -626,7 +623,7 @@ public class EPPLaunchTst extends TestCase {
 			Assert.fail("testTrademarkHolderEnglishActive(): Error creating Trademark-Holder-English-Active.smd file for signed mark: "
 					+ ex);
 		}
-		
+
 		EPPSignedMark signedMark2 = null;
 		try {
 			signedMark2 = new EPPSignedMark(signedMark.encode());
@@ -637,16 +634,13 @@ public class EPPLaunchTst extends TestCase {
 		}
 		if (!signedMark2.validate(pkixParameters)) {
 			Assert.fail("testTrademarkHolderEnglishActive(): Error validating signed mark 2");
-		}		
-				
+		}
+
 		System.out.println("testTrademarkHolderEnglishActive(): Success");
-		
+
 		EPPCodecTst.printEnd("testTrademarkHolderEnglishActive");
 	}
-	
-	
-	
-	
+
 	/**
 	 * Tests the <code>EPPLaunchInfo</code> info command extension. The tests
 	 * include the following:<br>
@@ -902,24 +896,24 @@ public class EPPLaunchTst extends TestCase {
 	}
 
 	/**
-	 * Tests the <code>EPPLaunchCheck</code> check command extension. The tests
+	 * Tests the <code>testLaunchClaimsCheckForm</code> check command extension. The tests
 	 * include the following:<br>
 	 * <br>
 	 * <ol>
-	 * <li>Test claims check command for "claims" form and "claims" launch phase
-	 * <li>Test claims check response for "claims" launch phase
-	 * <li>Test availability check command the custom "idn-release" launch phase
+	 * <li>Test Claims Check Form Command during the "claims" phase
+	 * <li>Test Claims Check Form Command during the "open" phase
+	 * <li>Test Claims Check Form Response
 	 * </ol>
 	 */
-	public void testLaunchCheck() {
+	public void testLaunchClaimsCheckForm() {
 
-		EPPCodecTst.printStart("testLaunchCheck");
+		EPPCodecTst.printStart("testLaunchClaimsCheckForm");
 
-		// Claims Check Command for "claims"
 		Vector domains = new Vector();
 		domains.addElement("example1.tld");
 		domains.addElement("example2.tld");
 
+		// Claims Check Form Command during the "claims" phase
 		EPPDomainCheckCmd theCommand = new EPPDomainCheckCmd("ABC-12345",
 				domains);
 
@@ -929,7 +923,18 @@ public class EPPLaunchTst extends TestCase {
 		EPPEncodeDecodeStats stats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(stats);
 
-		// Claims Check Command for "claims"
+		// Claims Check Form Command during the "open" phase
+		theCommand = new EPPDomainCheckCmd("ABC-12345",
+				domains);
+
+		theCommand.addExtension(new EPPLaunchCheck(new EPPLaunchPhase(
+				EPPLaunchPhase.PHASE_OPEN), EPPLaunchCheck.TYPE_CLAIMS));
+
+		stats = EPPCodecTst.testEncodeDecode(theCommand);
+		System.out.println(stats);
+		
+		
+		// Claims Check Form Response during the "claims" phase
 		EPPResponse theResponse;
 		EPPTransId respTransId = new EPPTransId("ABC-12345", "54322-XYZ");
 
@@ -939,27 +944,107 @@ public class EPPLaunchTst extends TestCase {
 		theExt.addCheckResult(new EPPLaunchCheckResult("example1.tld", false));
 		theExt.addCheckResult(new EPPLaunchCheckResult("example2.tld", true,
 				"2013041500/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000001"));
-		theExt.addCheckResult(new EPPLaunchCheckResult("example2.tld", true,
-				"2013111200/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000002", "tmch"));
+
+		EPPLaunchCheckResult launchCheckResult = new EPPLaunchCheckResult(
+				"example3.tld", true);
+		launchCheckResult.addClaimKey(
+				"2013041500/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000001", "tmch");
+		launchCheckResult.addClaimKey(
+				"20140423200/1/2/3/rJ1Nr2vDsAzasdff7EasdfgjX4R000000002",
+				"custom-tmch");
+		theExt.addCheckResult(launchCheckResult);
 
 		theResponse.addExtension(theExt);
 
 		stats = EPPCodecTst.testEncodeDecode(theResponse);
 		System.out.println(stats);
 
+		EPPCodecTst.printEnd("testLaunchClaimsCheckForm");
+	}
+
+	/**
+	 * Tests the <code>testLaunchAvailabilityCheckForm</code> check command extension. The tests
+	 * include the following:<br>
+	 * <br>
+	 * <ol>
+	 * <li>Test availability check command the custom "idn-release" launch phase
+	 * </ol>
+	 */
+	public void testLaunchAvailabilityCheckForm() {
+
+		EPPCodecTst.printStart("testLaunchAvailabilityCheckForm");
+
+		// Claims Check Command for "claims"
+		Vector domains = new Vector();
+		domains.addElement("example1.tld");
+		domains.addElement("example2.tld");
+
 		// Test availability check command the custom "idn-release" launch phase
-		theCommand = new EPPDomainCheckCmd("ABC-12345", domains);
+		EPPDomainCheckCmd theCommand = new EPPDomainCheckCmd("ABC-12345", domains);
 
 		theCommand.addExtension(new EPPLaunchCheck(new EPPLaunchPhase(
 				EPPLaunchPhase.PHASE_CUSTOM, "idn-release"),
 				EPPLaunchCheck.TYPE_AVAILABILITY));
 
-		stats = EPPCodecTst.testEncodeDecode(theCommand);
+		EPPEncodeDecodeStats stats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(stats);
 
-		EPPCodecTst.printEnd("testLaunchCheck");
+		EPPCodecTst.printEnd("testLaunchAvailabilityCheckForm");
 	}
+	
+	/**
+	 * Tests the <code>testLaunchTrademarkCheckForm</code> check command extension. The tests
+	 * include the following:<br>
+	 * <br>
+	 * <ol>
+	 * <li>Test Trademark Check Form Command
+	 * <li>Test Trademark Check Form Response
+	 * </ol>
+	 */
+	public void testLaunchTrademarkCheckForm() {
 
+		EPPCodecTst.printStart("testLaunchTrademarkCheckForm");
+
+		// Claims Check Command for "claims"
+		Vector domains = new Vector();
+		domains.addElement("example1.tld");
+		domains.addElement("example2.tld");
+
+		EPPDomainCheckCmd theCommand = new EPPDomainCheckCmd("ABC-12345",
+				domains);
+
+		theCommand.addExtension(new EPPLaunchCheck(EPPLaunchCheck.TYPE_TRADEMARK));
+
+		EPPEncodeDecodeStats stats = EPPCodecTst.testEncodeDecode(theCommand);
+		System.out.println(stats);
+
+		// Claims Check Command for "claims"
+		EPPResponse theResponse;
+		EPPTransId respTransId = new EPPTransId("ABC-12345", "54322-XYZ");
+
+		theResponse = new EPPResponse(respTransId);
+		EPPLaunchChkData theExt = new EPPLaunchChkData();
+		theExt.addCheckResult(new EPPLaunchCheckResult("example1.tld", false));
+		theExt.addCheckResult(new EPPLaunchCheckResult("example2.tld", true,
+				"2013041500/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000001"));
+
+		EPPLaunchCheckResult launchCheckResult = new EPPLaunchCheckResult(
+				"example3.tld", true);
+		launchCheckResult.addClaimKey(
+				"2013041500/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000001", "tmch");
+		launchCheckResult.addClaimKey(
+				"20140423200/1/2/3/rJ1Nr2vDsAzasdff7EasdfgjX4R000000002",
+				"custom-tmch");
+		theExt.addCheckResult(launchCheckResult);
+
+		theResponse.addExtension(theExt);
+
+		stats = EPPCodecTst.testEncodeDecode(theResponse);
+		System.out.println(stats);
+
+		EPPCodecTst.printEnd("testLaunchTrademarkCheckForm");
+	}
+	
 	/**
 	 * Tests the <code>EPPLaunchCreate</code> create command extension with use
 	 * of the code and mark in Sunrise Create Form. The tests include the
@@ -1004,9 +1089,11 @@ public class EPPLaunchTst extends TestCase {
 		EPPLaunchCreate createExt = new EPPLaunchCreate(new EPPLaunchPhase(
 				EPPLaunchPhase.PHASE_SUNRISE));
 
-		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AC", "sample1"));
+		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AC",
+				"sample1"));
 		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AD"));
-		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AE", "sample2"));
+		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AE",
+				"sample2"));
 
 		theCommand.setExtensions(null);
 		theCommand.addExtension(createExt);
@@ -1155,7 +1242,6 @@ public class EPPLaunchTst extends TestCase {
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
 
-		
 		// Test create command with mix of sunrise create model and claims
 		// create model with validatorID
 		theCommand.setExtensions(null);
@@ -1172,8 +1258,7 @@ public class EPPLaunchTst extends TestCase {
 
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
-		
-		
+
 		EPPCodecTst.printEnd("testLaunchCreateCodeMark");
 	}
 
@@ -1234,7 +1319,6 @@ public class EPPLaunchTst extends TestCase {
 
 		EPPCodecTst.printEnd("testLaunchCreateGeneric");
 	}
-	
 
 	/**
 	 * Tests the <code>EPPLaunchCreate</code> create command extension with use
@@ -1366,13 +1450,13 @@ public class EPPLaunchTst extends TestCase {
 		issuer.setVoiceExt("1234");
 
 		EPPSignedMark signedMark = null;
-		
+
 		// Sign the signed mark
 		try {
 			signedMark = new EPPSignedMark("1-123456", issuer,
 					new GregorianCalendar(2012, 8, 16).getTime(),
 					new GregorianCalendar(2013, 8, 16).getTime(), mark);
-			
+
 			signedMark.sign(privateKey, certChain);
 		}
 		catch (EPPException ex) {
@@ -1382,8 +1466,6 @@ public class EPPLaunchTst extends TestCase {
 		if (!signedMark.validate(publicKey)) {
 			Assert.fail("Signed mark validation error without encode/decode");
 		}
-		
-		
 
 		theCommand.setExtensions(null);
 		theCommand.addExtension(new EPPLaunchCreate(new EPPLaunchPhase(
@@ -1395,8 +1477,6 @@ public class EPPLaunchTst extends TestCase {
 		if (!signedMark.validate(pkixParameters)) {
 			Assert.fail("testLaunchCreateSignedMark(): XML signed mark signature is NOT valid after command encode/decode");
 		}
-				
-		
 
 		// Base64 encode the signed mark
 		EPPEncodedSignedMark encodedSignedMark = null;
@@ -1406,7 +1486,7 @@ public class EPPLaunchTst extends TestCase {
 		catch (EPPEncodeException e1) {
 			Assert.fail("testLaunchCreateSignedMark(): Error creating EPPEncodedSignedMark from signed mark");
 		}
-		catch ( EPPDecodeException e ) {
+		catch (EPPDecodeException e) {
 			Assert.fail("testLaunchCreateSignedMark(): Error creating EPPEncodedSignedMark from signed mark");
 		}
 
@@ -1416,7 +1496,6 @@ public class EPPLaunchTst extends TestCase {
 		if (!signedMark.validate(pkixParameters)) {
 			Assert.fail("testLaunchCreateSignedMark(): encoded signed mark signature is NOT valid after command encode/decode");
 		}
-				
 
 		EPPCodecTst.printEnd("testLaunchCreateSignedMark");
 	}
@@ -1458,18 +1537,22 @@ public class EPPLaunchTst extends TestCase {
 
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
-		
+
 		theCommand.setExtensions(null);
-		
-		// Test create command for claims create using the notice information and validatorID
-		theCommand.addExtension(new EPPLaunchCreate(new EPPLaunchPhase(
-				EPPLaunchPhase.PHASE_CLAIMS), new EPPLaunchNotice(
-				"49FD46E6C4B45C55D4AC", new Date(), new Date(), "tmch"),
-				EPPLaunchCreate.TYPE_REGISTRATION));
+
+		// Test create command for claims create using the notice information
+		// and validatorID's
+		EPPLaunchCreate launchCreate = new EPPLaunchCreate(new EPPLaunchPhase(
+				EPPLaunchPhase.PHASE_CLAIMS));
+		launchCreate.setType(EPPLaunchCreate.TYPE_REGISTRATION);
+		launchCreate.addNotice(new EPPLaunchNotice(
+				"370d0b7c9223372036854775807", new Date(), new Date(), "tmch"));
+		launchCreate.addNotice(new EPPLaunchNotice("470d0b7c9223654313275808",
+				new Date(), new Date(), "custom-tmch"));
+		theCommand.addExtension(launchCreate);
 
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
-		
 
 		EPPCodecTst.printEnd("testLaunchCreateNotice");
 	}
@@ -1640,7 +1723,6 @@ public class EPPLaunchTst extends TestCase {
 		EPPCodecTst.printEnd("testMark");
 	}
 
-
 	private static class SMDFilenameFilter implements FilenameFilter {
 		public boolean accept(File aDir, String aName) {
 			if (aName.endsWith(".smd")) {
@@ -1652,7 +1734,6 @@ public class EPPLaunchTst extends TestCase {
 		}
 	}
 
-	
 	/**
 	 * Read and validate the active SMD's.
 	 */
@@ -1678,7 +1759,7 @@ public class EPPLaunchTst extends TestCase {
 							+ activeSMDFiles[i].getName() + "\"");
 				}
 
-				EPPSignedMark signedMark = null;  
+				EPPSignedMark signedMark = null;
 
 				try {
 					signedMark = new EPPEncodedSignedMark(smdStream);
@@ -1701,7 +1782,7 @@ public class EPPLaunchTst extends TestCase {
 							+ activeSMDFiles[i].getName() + "\" is revoked");
 
 				}
-				
+
 				System.out.println("testActiveSMDs: Success with SMD \""
 						+ activeSMDFiles[i].getName() + "\"");
 			}
@@ -1710,7 +1791,6 @@ public class EPPLaunchTst extends TestCase {
 
 		EPPCodecTst.printEnd("testActiveSMDs");
 	}
-	
 
 	/**
 	 * Read and ensure SMD's signed by revoked certificate do not pass
@@ -1738,7 +1818,7 @@ public class EPPLaunchTst extends TestCase {
 							+ revokedCertSMDFiles[i].getName() + "\"");
 				}
 
-				EPPSignedMark signedMark = null;  
+				EPPSignedMark signedMark = null;
 
 				try {
 					signedMark = new EPPEncodedSignedMark(smdStream);
@@ -1766,7 +1846,6 @@ public class EPPLaunchTst extends TestCase {
 		EPPCodecTst.printEnd("testRevokedCertSMDs");
 	}
 
-
 	/**
 	 * Read and ensure invalid SMD's do not pass validation.
 	 */
@@ -1792,7 +1871,7 @@ public class EPPLaunchTst extends TestCase {
 							+ invalidSMDFiles[i].getName() + "\"");
 				}
 
-				EPPSignedMark signedMark = null;  
+				EPPSignedMark signedMark = null;
 
 				try {
 					signedMark = new EPPEncodedSignedMark(smdStream);
@@ -1846,7 +1925,7 @@ public class EPPLaunchTst extends TestCase {
 							+ revokedSMDFiles[i].getName() + "\"");
 				}
 
-				EPPSignedMark signedMark = null;  
+				EPPSignedMark signedMark = null;
 
 				try {
 					signedMark = new EPPEncodedSignedMark(smdStream);
@@ -1880,7 +1959,7 @@ public class EPPLaunchTst extends TestCase {
 
 		EPPCodecTst.printEnd("testRevokedSMDs");
 	}
-	
+
 	/**
 	 * JUNIT <code>setUp</code> method, which sets the default client Id to
 	 * "theRegistrar" and initializes the <code>EPPDomainMapFactory</code> with
@@ -1961,7 +2040,7 @@ public class EPPLaunchTst extends TestCase {
 			numIterations = Integer.parseInt(numIterProp);
 		}
 
-		// Add the EPPDomainMapFactory to the EPPCodec.
+		// Add the factories to the EPPCodec.
 		try {
 			EPPFactory.getInstance().addMapFactory(
 					"com.verisign.epp.codec.host.EPPHostMapFactory");
@@ -1974,7 +2053,7 @@ public class EPPLaunchTst extends TestCase {
 			Assert.fail("EPPCodecException adding EPPDomainMapFactory or EPPLaunchExtFactory to EPPCodec: "
 					+ e);
 		}
-		
+
 		// Get the appropriate smds directory.
 		smdsDir = "../lib/smds";
 		File smdsDirFile = new File(smdsDir);
@@ -1985,8 +2064,7 @@ public class EPPLaunchTst extends TestCase {
 				Assert.fail("EPPLaunchTst.suite(): Could not find the smds directory.");
 			}
 		}
-		
-		
+
 		return suite;
 	}
 
