@@ -1,15 +1,22 @@
-/*********************************************************************
- *                                                                   *
- * The information in this document is proprietary to VeriSign, Inc. *
- * It may not be used, reproduced or disclosed without the written   *
- * approval of VeriSign.                                             *
- *                                                                   *
- * VERISIGN PROPRIETARY & CONFIDENTIAL INFORMATION                   *
- *                                                                   *
- *                                                                   *
- * Copyright (c) 2012 VeriSign, Inc.  All rights reserved.           *
- *                                                                   *
- ********************************************************************/
+/***********************************************************
+Copyright (C) 2013 VeriSign, Inc.
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+http://www.verisign.com/nds/naming/namestore/techdocs.html
+ ***********************************************************/
 
 package com.verisign.epp.serverstub;
 
@@ -48,7 +55,6 @@ import com.verisign.epp.codec.registry.EPPRegistryDomainName;
 import com.verisign.epp.codec.registry.EPPRegistryDomainPeriod;
 import com.verisign.epp.codec.registry.EPPRegistryExternalHost;
 import com.verisign.epp.codec.registry.EPPRegistryFields;
-import com.verisign.epp.codec.registry.EPPRegistryRelated;
 import com.verisign.epp.codec.registry.EPPRegistryGracePeriod;
 import com.verisign.epp.codec.registry.EPPRegistryHost;
 import com.verisign.epp.codec.registry.EPPRegistryIDN;
@@ -66,14 +72,15 @@ import com.verisign.epp.codec.registry.EPPRegistryPostal;
 import com.verisign.epp.codec.registry.EPPRegistryRGP;
 import com.verisign.epp.codec.registry.EPPRegistryRedemptionPeriodType;
 import com.verisign.epp.codec.registry.EPPRegistryRegex;
+import com.verisign.epp.codec.registry.EPPRegistryRelated;
 import com.verisign.epp.codec.registry.EPPRegistryReservedNames;
 import com.verisign.epp.codec.registry.EPPRegistrySLA;
 import com.verisign.epp.codec.registry.EPPRegistrySLAInfo;
 import com.verisign.epp.codec.registry.EPPRegistryServices;
-import com.verisign.epp.codec.registry.EPPRegistryServicesExt;
-import com.verisign.epp.codec.registry.EPPRegistrySupportedStatus;
 import com.verisign.epp.codec.registry.EPPRegistryServices.EPPRegistryObjURI;
+import com.verisign.epp.codec.registry.EPPRegistryServicesExt;
 import com.verisign.epp.codec.registry.EPPRegistryServicesExt.EPPRegistryExtURI;
+import com.verisign.epp.codec.registry.EPPRegistrySupportedStatus;
 import com.verisign.epp.codec.registry.EPPRegistrySupportedStatus.Status;
 import com.verisign.epp.codec.registry.EPPRegistryTransferHoldPeriodType;
 import com.verisign.epp.codec.registry.EPPRegistryUpdateCmd;
@@ -365,7 +372,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 			EPPRegistryZoneInfo zoneInfo = null;
 			for (Iterator it = availableTlds.iterator(); it.hasNext();) {
 				EPPRegistryZoneInfo ti = (EPPRegistryZoneInfo) it.next();
-				if (ti.getName().equals(message.getName())) {
+				if (ti.getName().equalsIgnoreCase(message.getName())) {
 					zoneInfo = ti;
 					zoneInfo.setGroup("1");
 					if (zoneInfo.getName().length() == 0) {
@@ -384,7 +391,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 				}
 			}
 			if (zoneInfo != null) {
-				if ("com".equals(zoneInfo.getName())) {
+				if ("com".equalsIgnoreCase(zoneInfo.getName())) {
 					if (zoneInfo.getRelated() == null) {
 						EPPRegistryRelated related = new EPPRegistryRelated();
 						
